@echo off & setlocal EnableDelayedExpansion 
:: Arguments: 
:: 1. save path (where to save) 	=> the path to the folder where the simulation data shall be saved
:: 2. path to config.xml 			=> the path to the configuration xml file
:: 3. path to technical.xml 		=> the path to the technical xml file

::You have to update this path to run the script!
set simPath=D:\Test\CaTSiT

::check whether the simulation path exists
if not exist %simPath% (
	echo The stated path to the CaTSiT folder '%simPath%' does not exist. Did you forgot to update the path before using this script?
	exit /b
)

:: check if all 3 parameter where stated
if "%3"=="" (
	<nul set /p="usage: %0 'folder name (where to save)' 'path to configuration.xml' 'path to technical.xml'"
	exit /b
)
if "%2"=="" (
	<nul set /p="usage: %0 'folder name (where to save)' 'path to configuration.xml' 'path to technical.xml'"
	exit /b
)
if "%1"=="" (
	<nul set /p="usage: %0 'folder name (where to save)' 'path to configuration.xml' 'path to technical.xml'"
	exit /b
)

::check if the simulation configuration file exists
if not exist %2 (
	echo simulation configuration %2% does not exist.
	exit /b
)

::check if the technical configuration file exists
if not exist %3 (
  echo technical configuration %3% does not exist.
  exit /b
)

::define the sim data folder
set simdataFolder=%1

if not exist %simdataFolder% (
  ::create the folder structure
  mkdir %simdataFolder%
)

::change into the project folder
cd %simPath%

::start the SimController
echo Starting simulation %2
<nul set /p="Starting simrun 0 ... "
java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar simulate %simdataFolder%/data.xlsx "simrun_0" %2 %3 
echo finshed simrun 0.

set numberOfOrgans=0
for /F "tokens=*" %%f in ('dir /S /b %simdataFolder%\data_*') do (
	set /a numberOfOrgans=!numberOfOrgans!+1
	set string=%%~nf
	set organs[!numberOfOrgans!]=!string:~5!
)

for /l %%X in (1,1,99) do ( REM change the last number in the brackets to change the number of iterations. We start counting from 0. Hence a value of 99 means 100 iterations
  <nul set /p="Starting simrun %%X ... "
  java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar simulate %simdataFolder%/data_%%X.xlsx "simrun_%%X" %2 %3 
  
  <nul set /p="merging... "
  java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar merge %simdataFolder%/data.xlsx %simdataFolder%/data_%%X.xlsx
  del "%simdataFolder%\data_%%X.xlsx"
  
  ::merging organ files
  for /l %%i in (1,1,%numberOfOrgans%) do (
	java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar merge "%simdataFolder%/data_!organs[%%i]!.xlsx" "%simdataFolder%/data_%%X_!organs[%%i]!.xlsx"
	del "%simdataFolder%\data_%%X_!organs[%%i]!.xlsx"
  )  

  echo finshed simrun %%X.
)

echo zipping file
java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar zip %simdataFolder%/data.xlsx

::zipping organ files
for /l %%i in (1,1,%numberOfOrgans%) do (
	java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar zip "%simdataFolder%/data_!organs[%%i]!.xlsx"
)

::copy the log file and the configuration files to the sim folder
echo copying configuration and log files
move catsit*.log %simdataFolder%
copy %2 %simdataFolder%
copy %3 %simdataFolder%
echo All done!

::back to the starting directory
cd %~dp0