#!/bin/bash
# Arguments: 
#1. save path (where to save) 	=> the path to the folder where the simulation data shall be saved
#2. path to config.xml 		=> the path to the configuration xml file
#3. path to technical.xml 	=> the path to the technical xml file

#You have to update this path to run the script!
simPath="/home/anja/CaTSiT"

#check whether the simulation path exists
if [ ! -e "$simPath" ]
then
  echo "The stated path to the CaTSiT folder '$simPath' does not exist. Did you forgot to update the path before using this script?"
  exit 1
fi

#check the number of parameter
if [ $# -ne 3 ]
then
  echo "usage: $0 'folder name (where to save)' 'path to config.xml' 'path to technical.xml'"
  exit 1
fi

#check if the simulation configuration file exists
if [ ! -e "$2" ]
then
  echo "simulation configuration $2 does not exist."
  exit 1
fi

#check if the technical configuration file exists
if [ ! -e "$3" ]
then
  echo "technical configuration $3 does not exist."
  exit 1
fi


#define the sim data folder
simdataFolder=$1

if [ ! -e "$simdataFolder" ]
then
  #create the folder structure
  mkdir -p $simdataFolder
fi

#change into the project folder
cd $simPath

#start the SimController
counter=0

echo "Starting simulation $2"
echo -n "Starting simrun $counter on `date +%d.%m.%y` at `date +%H:%M:%S` ... "
java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar simulate ${simdataFolder}/data.xlsx "simrun_$counter" ${2} ${3} 
echo "finshed simrun ${counter}."
counter=$(($counter+1))

#get the names of the printed organs, if any
i=0
for file in ${simdataFolder}/*data_*.xlsx
do
  if [ -e "$file" ]
  then
    removedPrefix=${file##*/data_}
    organList[$i]=${removedPrefix%%.xlsx}
    i=$(($i+1))
  fi
done


while [ $counter -lt 100 ] #change this number to change the number of iterations to run
do
  echo -n "Starting simrun $counter on `date +%d.%m.%y` at `date +%H:%M:%S` ... "
  java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar simulate ${simdataFolder}/data_${counter}.xlsx "simrun_$counter" ${2} ${3} 
  
  
  echo -n "merging... "
  #merging main file
  java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar merge ${simdataFolder}/data.xlsx ${simdataFolder}/data_${counter}.xlsx
  rm ${simdataFolder}/data_${counter}.xlsx

  #merging organ files
  for organ in "${organList[@]}"
  do
    java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar merge "\"${simdataFolder}/data_${organ}.xlsx\"" "\"${simdataFolder}/data_${counter}_${organ}.xlsx\""
    rm "${simdataFolder}/data_${counter}_${organ}.xlsx"
  done  
  
  echo "finshed simrun $counter ."
  counter=$(($counter+1))
done

echo "zipping file"
#zipping main file
java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar zip ${simdataFolder}/data.xlsx

#zipping organ files
for organ in "${organList[@]}"
do
  java -jar -Djava.util.logging.config.file=logging.properties CaTSiT.jar zip "${simdataFolder}/data_${organ}.xlsx"
done

#copy the log file and the configuration files to the sim folder
echo "copying configuration and log files"
mv catsit*.log $simdataFolder
cp $2 $simdataFolder
cp $3 $simdataFolder
echo "All done!"
